@@ -2,7 +2,7 @@
 **  Copyright (c) 2007-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009-2014, The Trusted Domain Project.  All rights reserved.
+**  Copyright (c) 2009-2015, The Trusted Domain Project.  All rights reserved.
 */
 
 #include "build-config.h"
@@ -354,7 +354,7 @@ dkim_canon_header_string(struct dkim_dstring *dstr, dkim_canon_t canon,
 			if (isascii(*p))
 			{
 				/* discard spaces */
-				if (DKIM_ISWSP(*p))
+				if (DKIM_ISLWSP(*p))
 					continue;
 
 				/* convert to lowercase */
