@@ -2,7 +2,7 @@
 **  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009-2013, The Trusted Domain Project.  All rights reserved.
+**  Copyright (c) 2009-2015, The Trusted Domain Project.  All rights reserved.
 */
 
 /* system includes */
@@ -355,7 +355,7 @@ dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 	if (txtfound == NULL)
 	{
 		dkim_error(dkim, "'%s' reply was unresolved CNAME", qname);
-		return DKIM_STAT_KEYFAIL;
+		return DKIM_STAT_NOKEY;
 	}
 
 	/* come back to the one we found */
@@ -494,7 +494,7 @@ dkim_get_key_file(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 
 		if (strcasecmp((char *) name, (char *) buf) == 0 && p2 != NULL)
 		{
-			strlcpy((char *) buf, (char *) p2, buflen);
+			memmove(buf, p2, strlen(p2) + 1);
 			fclose(f);
 			return DKIM_STAT_OK;
 		}
