@@ -2,7 +2,8 @@
 **  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
+**  Copyright (c) 2009-2012, 2014, The Trusted Domain Project.
+**  	All rights reserved.
 */
 
 /* system includes */
@@ -27,7 +28,7 @@ static struct nametable prv_keyparams[] =	/* key parameters */
 };
 struct nametable *keyparams = prv_keyparams;
 
-static struct nametable prv_keyflags[] =	/* policy flags */
+static struct nametable prv_keyflags[] =	/* key flags */
 {
 	{ "y",		DKIM_SIGFLAG_TESTKEY },
 	{ "s",		DKIM_SIGFLAG_NOSUBDOMAIN },
@@ -35,33 +36,6 @@ static struct nametable prv_keyflags[] =	/* policy flags */
 };
 struct nametable *keyflags = prv_keyflags;
 
-static struct nametable prv_policyparams[] =	/* policy parameters */
-{
-	{ "atps",	DKIM_PPARAM_ATPS },
-	{ "dkim",	DKIM_PPARAM_POLICY },
-	{ "r",		DKIM_PPARAM_REPORTADDR },
-	{ NULL,		-1 }
-};
-struct nametable *policyparams = prv_policyparams;
-
-static struct nametable prv_policies[] =	/* policies */
-{
-	{ "unknown",	DKIM_POLICY_UNKNOWN },
-	{ "all",	DKIM_POLICY_ALL },
-	{ "discardable", DKIM_POLICY_DISCARDABLE },
-	{ NULL,		-1 }
-};
-struct nametable *policies = prv_policies;
-
-static struct nametable prv_policyresults[] =	/* policy results */
-{
-	{ "none",				DKIM_PRESULT_NONE },
-	{ "author domain policy found",		DKIM_PRESULT_FOUND },
-	{ "domain does not exist",		DKIM_PRESULT_NXDOMAIN },
-	{ NULL,					-1 }
-};
-struct nametable *policyresults = prv_policyresults;
-
 static struct nametable prv_sigparams[] =	/* signature parameters */
 {
 	{ "a",		DKIM_PARAM_SIGNALG },
@@ -144,10 +118,9 @@ struct nametable *results = prv_results;
 
 static struct nametable prv_settypes[] =	/* set types */
 {
-	{ "key",	DKIM_SETTYPE_KEY },
-	{ "policy",	DKIM_SETTYPE_POLICY },
-	{ "signature",	DKIM_SETTYPE_SIGNATURE },
-	{ "signature reporting", DKIM_SETTYPE_SIGREPORT },
+	{ "key",			DKIM_SETTYPE_KEY },
+	{ "signature",			DKIM_SETTYPE_SIGNATURE },
+	{ "signature reporting", 	DKIM_SETTYPE_SIGREPORT },
 	{ NULL,		-1 },
 };
 struct nametable *settypes = prv_settypes;
