@@ -2,7 +2,7 @@
 **  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009, 2010, 2012, The Trusted Domain Project.
+**  Copyright (c) 2009, 2010, 2012, 2014, The Trusted Domain Project.
 **    All rights reserved.
 */
 
@@ -33,9 +33,6 @@ extern struct nametable *hashes;
 extern struct nametable *keyflags;
 extern struct nametable *keyparams;
 extern struct nametable *keytypes;
-extern struct nametable *policies;
-extern struct nametable *policyparams;
-extern struct nametable *policyresults;
 extern struct nametable *querytypes;
 extern struct nametable *results;
 extern struct nametable *settypes;
