@@ -2,7 +2,7 @@
 **  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009-2013, The Trusted Domain Project.  All rights reserved.
+**  Copyright (c) 2009-2014, The Trusted Domain Project.  All rights reserved.
 */
 
 #ifndef _DKIM_TYPES_H_
@@ -70,16 +70,6 @@ struct dkim_queryinfo
 	const char		dq_name[DKIM_MAXHOSTNAMELEN + 1];
 };
 
-/* struct dkim_pstate -- policy query state */
-struct dkim_pstate
-{
-	unsigned int		ps_pflags;
-	int			ps_qstatus;
-	int			ps_state;
-	dkim_policy_t		ps_policy;
-	DKIM *			ps_dkim;
-};
-
 /* struct dkim_dstring -- a dynamically-sized string */
 struct dkim_dstring
 {
@@ -292,7 +282,6 @@ struct dkim
 #endif /* QUERY_CACHE */
 	u_int			dkim_version;
 	u_int			dkim_sigcount;
-	int			dkim_dnssec_policy;
 	size_t			dkim_margin;
 	size_t			dkim_b64siglen;
 	size_t			dkim_keylen;
@@ -366,7 +355,6 @@ struct dkim_lib
 	u_int *			dkiml_flist;
 	void *			(*dkiml_malloc) (void *closure, size_t nbytes);
 	void			(*dkiml_free) (void *closure, void *p);
-	u_char **		dkiml_senderhdrs;
 	u_char **		dkiml_requiredhdrs;
 	u_char **		dkiml_oversignhdrs;
 	u_char **		dkiml_mbs;
@@ -379,12 +367,6 @@ struct dkim_lib
 				                     DKIM_SIGINFO *sig,
 				                     u_char *buf,
 				                     size_t buflen);
-	DKIM_CBSTAT		(*dkiml_policy_lookup) (DKIM *dkim,
-				                        u_char *query,
-				                        _Bool excheck,
-				                        u_char *buf,
-				                        size_t buflen,
-				                        int *qstat);
 	void *			(*dkiml_sig_handle) (void *closure);
 	void			(*dkiml_sig_handle_free) (void *closure,
 				                          void *user);
