@@ -2,13 +2,9 @@
 **  Copyright (c) 2007, 2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009-2012, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
 */
 
-#ifndef lint
-static char t_testdata_h[] = "@(#)$Id: t-testdata.h,v 1.2 2010/07/23 01:54:20 cm-msk Exp $";
-#endif /* !lint */
-
 
 #define	CRLF		"\r\n"
 #define	SP		" "
@@ -16,7 +12,7 @@ static char t_testdata_h[] = "@(#)$Id: t-testdata.h,v 1.2 2010/07/23 01:54:20 cm
 #define	LARGEBODYSIZE	65536
 #define	LARGELINESIZE	4100
 
-#define	KEYFILE		"/var/tmp/testkeys"
+#define	KEYFILE		"/tmp/testkeys"
 
 #define	JOBID		"testing"
 #define	SELECTOR	"test"
