@@ -1,5 +1,5 @@
 /*
-**  Copyright (c) 2010-2014, The Trusted Domain Project.  All rights reserved.
+**  Copyright (c) 2010-2015, The Trusted Domain Project.  All rights reserved.
 */
 
 #include "build-config.h"
@@ -401,7 +401,7 @@ main(int argc, char **argv)
 		char path[MAXPATHLEN + 1];
 
 		cfg = config_load(configfile, dkimf_config,
-		                  &line, path, sizeof path);
+		                  &line, path, sizeof path, NULL);
 
 		if (cfg == NULL)
 		{
