@@ -1,5 +1,5 @@
 /*
-**  Copyright (c) 2009-2013, The Trusted Domain Project.  All rights reserved.
+**  Copyright (c) 2009-2015, The Trusted Domain Project.  All rights reserved.
 */
 
 #include "build-config.h"
@@ -107,7 +107,6 @@ static const luaL_Reg dkimf_lua_lib_stats[] =
 	{ "get_envfrom",	dkimf_xs_getenvfrom	},
 	{ "get_header",		dkimf_xs_getheader	},
 	{ "get_mtasymbol",	dkimf_xs_getsymval	},
-	{ "get_policy",		dkimf_xs_getpolicy	},
 	{ "get_rcpt",		dkimf_xs_rcpt		},
 	{ "get_rcptarray",	dkimf_xs_rcptarray	},
 	{ "get_sigarray",	dkimf_xs_getsigarray	},
@@ -145,7 +144,6 @@ static const luaL_Reg dkimf_lua_lib_final[] =
 	{ "get_fromdomain",	dkimf_xs_fromdomain	},
 	{ "get_header",		dkimf_xs_getheader	},
 	{ "get_mtasymbol",	dkimf_xs_getsymval	},
-	{ "get_policy",		dkimf_xs_getpolicy	},
 	{ "get_rcpt",		dkimf_xs_rcpt		},
 	{ "get_rcptarray",	dkimf_xs_rcptarray	},
 	{ "get_sigarray",	dkimf_xs_getsigarray	},
@@ -511,6 +509,8 @@ dkimf_lua_setup_hook(void *ctx, const char *script, size_t scriptlen,
 	lua_setglobal(l, "DB_MTAS");
 	lua_pushnumber(l, DB_MACROS);
 	lua_setglobal(l, "DB_MACROS");
+	lua_pushnumber(l, DB_SIGNINGTABLE);
+	lua_setglobal(l, "DB_SIGNINGTABLE");
 
 	/* set result code */
 	lua_pushnumber(l, SMFIS_TEMPFAIL);
@@ -664,6 +664,8 @@ dkimf_lua_screen_hook(void *ctx, const char *script, size_t scriptlen,
 	lua_setglobal(l, "DB_MTAS");
 	lua_pushnumber(l, DB_MACROS);
 	lua_setglobal(l, "DB_MACROS");
+	lua_pushnumber(l, DB_SIGNINGTABLE);
+	lua_setglobal(l, "DB_SIGNINGTABLE");
 
 	/* milter context */
 	lua_pushlightuserdata(l, ctx);
@@ -796,18 +798,6 @@ dkimf_lua_stats_hook(void *ctx, const char *script, size_t scriptlen,
 	lua_pushlightuserdata(l, &gc);
 	lua_setglobal(l, DKIMF_GC);
 
-	/* policy codes */
-	lua_pushnumber(l, DKIMF_POLICY_UNKNOWN);
-	lua_setglobal(l, "DKIMF_POLICY_UNKNOWN");
-	lua_pushnumber(l, DKIMF_POLICY_ALL);
-	lua_setglobal(l, "DKIMF_POLICY_ALL");
-	lua_pushnumber(l, DKIMF_POLICY_DISCARDABLE);
-	lua_setglobal(l, "DKIMF_POLICY_DISCARDABLE");
-	lua_pushnumber(l, DKIMF_POLICY_NONE);
-	lua_setglobal(l, "DKIMF_POLICY_NONE");
-	lua_pushnumber(l, DKIMF_POLICY_NXDOMAIN);
-	lua_setglobal(l, "DKIMF_POLICY_NXDOMAIN");
-
 	/* milter result codes */
 	lua_pushnumber(l, SMFIS_TEMPFAIL);
 	lua_setglobal(l, "SMFIS_TEMPFAIL");
@@ -1045,18 +1035,6 @@ dkimf_lua_final_hook(void *ctx, const char *script, size_t scriptlen,
 	lua_pushlightuserdata(l, &gc);
 	lua_setglobal(l, DKIMF_GC);
 
-	/* policy codes */
-	lua_pushnumber(l, DKIMF_POLICY_UNKNOWN);
-	lua_setglobal(l, "DKIMF_POLICY_UNKNOWN");
-	lua_pushnumber(l, DKIMF_POLICY_ALL);
-	lua_setglobal(l, "DKIMF_POLICY_ALL");
-	lua_pushnumber(l, DKIMF_POLICY_DISCARDABLE);
-	lua_setglobal(l, "DKIMF_POLICY_DISCARDABLE");
-	lua_pushnumber(l, DKIMF_POLICY_NONE);
-	lua_setglobal(l, "DKIMF_POLICY_NONE");
-	lua_pushnumber(l, DKIMF_POLICY_NXDOMAIN);
-	lua_setglobal(l, "DKIMF_POLICY_NXDOMAIN");
-
 	/* milter result codes */
 	lua_pushnumber(l, SMFIS_TEMPFAIL);
 	lua_setglobal(l, "SMFIS_TEMPFAIL");
