@@ -2,18 +2,13 @@
 **  Copyright (c) 2007 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  Copyright (c) 2009-2011, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
 **
-**  $Id: stats.h,v 1.10.2.1 2010/10/27 21:43:09 cm-msk Exp $
 */
 
 #ifndef _STATS_H_
 #define _STATS_H_
 
-#ifndef lint
-static char stats_h_id[] = "@(#)$Id: stats.h,v 1.10.2.1 2010/10/27 21:43:09 cm-msk Exp $";
-#endif /* !lint */
-
 /* system includes */
 #include <sys/param.h>
 #include <sys/types.h>
