@@ -2,7 +2,7 @@
 **  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  Copyright (c) 2009-2013, The Trusted Domain Project.  All rights reserved.
+**  Copyright (c) 2009-2014, The Trusted Domain Project.  All rights reserved.
 */
 
 #include "build-config.h"
@@ -124,10 +124,6 @@ static char *optlist[] =
 	"USE_UNBOUND",
 #endif /* USE_UNBOUND */
 
-#if USE_XML2
-	"USE_XML2",
-#endif /* USE_XML2 */
-
 #ifdef _FFR_ADSP_LISTS
 	"_FFR_ADSP_LISTS",
 #endif /* _FFR_ADSP_LISTS */
@@ -144,10 +140,6 @@ static char *optlist[] =
 	"_FFR_DIFFHEADERS",
 #endif /* _FFR_DIFFHEADERS */
 
-#if _FFR_DKIM_REPUTATION
-	"_FFR_DKIM_REPUTATION",
-#endif /* _FFR_DKIM_REPUTATION */
-
 #if _FFR_IDENTITY_HEADER
 	"_FFR_IDENTITY_HEADER",
 #endif /* _FFR_IDENTITY_HEADER */
@@ -156,6 +148,10 @@ static char *optlist[] =
 	"_FFR_LDAP_CACHING",
 #endif /* _FFR_LDAP_CACHING */
 
+#if _FFR_LUA_ONLY_SIGNING
+	"_FFR_LUA_ONLY_SIGNING",
+#endif /* _FFR_LUA_ONLY_SIGNING */
+
 #if _FFR_POSTGRESQL_RECONNECT_HACK
 	"_FFR_POSTGRESQL_RECONNECT_HACK",
 #endif /* _FFR_POSTGRESQL_RECONNECT_HACK */
@@ -168,10 +164,6 @@ static char *optlist[] =
 	"_FFR_RBL",
 #endif /* _FFR_RBL */
 
-#if _FFR_REDIRECT
-	"_FFR_REDIRECT",
-#endif /* _FFR_REDIRECT */
-
 #if _FFR_REPLACE_RULES
 	"_FFR_REPLACE_RULES",
 #endif /* _FFR_REPLACE_RULES */
@@ -389,14 +381,12 @@ dkimf_checkhost(DKIMF_DB db, char *host)
 
 	assert(host != NULL);
 
-	/* short circuit */
-	if (db == NULL)
+	/* short circuits */
+	if (db == NULL || host[0] == '\0')
 		return FALSE;
 
 	/* iterate over the possibilities */
-	for (p = host;
-	     p != NULL;
-	     p = (p == host ? strchr(host, '.') : strchr(p + 1, '.')))
+	for (p = host; p != NULL; p = strchr(p + 1, '.'))
 	{
 		/* try the negative case */
 		snprintf(buf, sizeof buf, "!%s", p);
