@@ -2,18 +2,14 @@
 **  Copyright (c) 2004, 2005, 2007-2009 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  Copyright (c) 2009, 2010, 2012, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009, 2010, 2012, The Trusted Domain Project.
+**    All rights reserved.
 **
-**  $Id: util.h,v 1.11.10.1 2010/10/27 21:43:09 cm-msk Exp $
 */
 
 #ifndef _UTIL_H_
 #define _UTIL_H_
 
-#ifndef lint
-static char util_h_id[] = "@(#)$Id: util.h,v 1.11.10.1 2010/10/27 21:43:09 cm-msk Exp $";
-#endif /* !lint */
-
 /* system includes */
 #include <sys/types.h>
 #include <sys/socket.h>
